package com.nto.presentation.screens.loginScreen

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import androidx.navigation.compose.rememberNavController
import com.nto.presentation.R
import com.nto.presentation.composable.InputField
import com.nto.presentation.composable.InputFieldOptions
import com.nto.presentation.theme.NTOTheme

@Composable
fun LoginScreen(
    navController: NavHostController,
    modifier: Modifier = Modifier,
    viewModel: LoginViewModel = hiltViewModel<LoginViewModel>(),
) {
    val state = viewModel.state.collectAsState().value

    Column(
        modifier = modifier.background(NTOTheme.colors.secondaryBackground),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Row(modifier = Modifier.fillMaxWidth(), horizontalArrangement = Arrangement.SpaceBetween) {
            Image(
                painter = painterResource(R.drawable.elipse),
                modifier = Modifier.size(140.dp),
                contentScale = ContentScale.FillBounds,
                contentDescription = null
            )
            Image(
                painter = painterResource(R.drawable.triangle),
                modifier = Modifier.padding(vertical = 20.dp),
                contentScale = ContentScale.FillBounds,
                contentDescription = null
            )
        }
        Text(
            text = stringResource(R.string.greeting_login),
            style = NTOTheme.typography.titleLarge,
            color = NTOTheme.colors.secondaryText,
            textAlign = TextAlign.Center
        )
        Spacer(modifier = Modifier.height(5.dp))
        Text(
            text = stringResource(R.string.greeting_login_description),
            style = NTOTheme.typography.displaySmall,
            color = NTOTheme.colors.secondaryText,
            textAlign = TextAlign.Center
        )
        Spacer(modifier = Modifier.height(60.dp))
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .fillMaxSize()
                .clip(
                    RoundedCornerShape(topStart = 21.dp, topEnd = 21.dp)
                )
                .background(NTOTheme.colors.primaryBackground)
                .padding(40.dp)
        ) {
            Column(modifier = Modifier.fillMaxWidth()) {
                Text(
                    stringResource(R.string.text_email),
                    style = NTOTheme.typography.displaySmall,
                    modifier = Modifier.padding(start = 10.dp),
                    fontSize = 14.sp
                )
                Spacer(modifier = Modifier.height(5.dp))
                InputField(
                    state.email,
                    placeholder = stringResource(R.string.placholder_email),
                    onValueChange = viewModel::setEmail
                )
            }
            Spacer(modifier = Modifier.height(20.dp))
            Column(modifier = Modifier.fillMaxWidth()) {
                Text(
                    stringResource(R.string.text_password),
                    style = NTOTheme.typography.displaySmall,
                    modifier = Modifier.padding(start = 10.dp),
                    fontSize = 14.sp
                )
                Spacer(modifier = Modifier.height(5.dp))
                InputField(
                    state.password,
                    placeholder = stringResource(R.string.placeholder_password),
                    options = InputFieldOptions(isConfidential = true),
                    onValueChange = viewModel::setPassword
                )
            }
            Spacer(Modifier.height(50.dp))
            //TODO: LoginButton
        }
    }
}

@Preview
@Composable
private fun LoginPreview() {
    NTOTheme {
        LoginScreen(rememberNavController(), Modifier.fillMaxSize())
    }
}