package com.nto.presentation.theme

import android.annotation.SuppressLint
import androidx.compose.runtime.Immutable
import androidx.compose.runtime.staticCompositionLocalOf
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.sp
import com.nto.presentation.R

private val RalewayFontFamily = FontFamily(
    Font(R.font.raleway)
)

private val PlayfairFontFamily = FontFamily(
    Font(R.font.playfair)
)

@Immutable
data class AppTypography(
    val titleLarge: TextStyle,
    val displaySmall: TextStyle,
    val placeholder: TextStyle
)

@SuppressLint("ComposeCompositionLocalUsage")
val LocalAppTypography = staticCompositionLocalOf {
    AppTypography(
        titleLarge = TextStyle.Default,
        displaySmall = TextStyle.Default,
        placeholder = TextStyle.Default
    )
}

val extendedTypography = AppTypography(
    titleLarge = TextStyle(
        fontFamily = PlayfairFontFamily,
        fontSize = 48.sp,
    ),
    displaySmall = TextStyle(
        fontFamily = RalewayFontFamily,
        fontSize = 16.sp,
    ),
    placeholder = TextStyle(
        fontFamily = RalewayFontFamily,
        fontSize = 14.sp,
        fontWeight = FontWeight.Bold,
    )
)